weaviate.collections
============

.. automodule:: weaviate.collections
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.aggregations
============

.. automodule:: weaviate.collections.aggregations
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.batch
============

.. automodule:: weaviate.collections.batch
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.classes
============

.. automodule:: weaviate.collections.classes
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.grpc
============

.. automodule:: weaviate.collections.grpc
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries
============

.. automodule:: weaviate.collections.queries
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.bm25
============

.. automodule:: weaviate.collections.queries.bm25
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.fetch_objects
============

.. automodule:: weaviate.collections.queries.fetch_objects
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.hybrid
============

.. automodule:: weaviate.collections.queries.hybrid
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near_audio
============

.. automodule:: weaviate.collections.queries.near_audio
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near_image
============

.. automodule:: weaviate.collections.queries.near_image
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near_object
============

.. automodule:: weaviate.collections.queries.near_object
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near_text
============

.. automodule:: weaviate.collections.queries.near_text
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near_vector
============

.. automodule:: weaviate.collections.queries.near_vector
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.collections.queries.near_video
============

.. automodule:: weaviate.collections.queries.near_video
   :members:
   :undoc-members:
   :show-inheritance: